# -*- encoding: utf-8 -*-

# Copyright 2013 OpenStack Foundation
# All Rights Reserved.
# Copyright 2013 IBM Corp.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from sqlalchemy import MetaData
from sqlalchemy import String
from sqlalchemy import Table
from sqlalchemy import Text


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    alm_hist = Table('alarm_history', meta, autoload=True)
    alm_hist.c.detail.alter(type=Text)


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    alm_hist = Table('alarm_history', meta, autoload=True)
    alm_hist.c.detail.alter(type=String(255))
